package java.awt;

import java.io.Serializable;
import java.awt.image.ImageObserver;

class ImageMediaEntry extends MediaEntry implements ImageObserver, Serializable
{
    Image image;
    int width;
    int height;
    private static final long serialVersionUID = 4739377000350280650L;
    
    ImageMediaEntry(MediaTracker mediaTracker, Image image, int n, int width, int height) {
        super(mediaTracker, n);
        this.image = image;
        this.width = width;
        this.height = height;
    }
    
    boolean matches(Image image, int n, int n2) {
        return this.image == image && this.width == n && this.height == n2;
    }
    
    @Override
    Object getMedia() {
        return this.image;
    }
    
    @Override
    synchronized int getStatus(boolean b, boolean b2) {
        if (b2) {
            int parseflags = this.parseflags(this.tracker.target.checkImage(this.image, this.width, this.height, null));
            if (parseflags == 0) {
                if ((this.status & 0xC) != 0x0) {
                    this.setStatus(2);
                }
            }
            else if (parseflags != this.status) {
                this.setStatus(parseflags);
            }
        }
        return super.getStatus(b, b2);
    }
    
    @Override
    void startLoad() {
        if (this.tracker.target.prepareImage(this.image, this.width, this.height, this)) {
            this.setStatus(8);
        }
    }
    
    int parseflags(int n) {
        if ((n & 0x40) != 0x0) {
            return 4;
        }
        if ((n & 0x80) != 0x0) {
            return 2;
        }
        if ((n & 0x30) != 0x0) {
            return 8;
        }
        return 0;
    }
    
    @Override
    public boolean imageUpdate(Image image, int n, int n2, int n3, int n4, int n5) {
        if (this.cancelled) {
            return false;
        }
        int parseflags = this.parseflags(n);
        if (parseflags != 0 && parseflags != this.status) {
            this.setStatus(parseflags);
        }
        return (this.status & 0x1) != 0x0;
    }
}
